pub enum MutateError {
ToolNotInstalled,
SubprocessFailed(String),
ParseError(String),
}Expand description
Errors that can arise during a mutation testing run.
Variants
ToolNotInstalled
cargo-mutants is not installed.
SubprocessFailed(String)
Subprocess returned a fatal error and no parseable JSON.
ParseError(String)
JSON output could not be parsed.